//
//  SourceEditorCommand.swift
//  FooBar
//
//  Created by Syo Ikeda on 10/31/16.
//  Copyright © 2016 Syo Ikeda. All rights reserved.
//

import Foundation
import XcodeKit

class SourceEditorCommand: NSObject, XCSourceEditorCommand {
    
    func perform(with invocation: XCSourceEditorCommandInvocation, completionHandler: @escaping (Error?) -> Void ) -> Void {
        let regex = try! NSRegularExpression(pattern: "(\\?[.\\[]?)", options: [])

        let buffer = invocation.buffer
        let selection = buffer.selections.firstObject as! XCSourceTextRange

        let start = selection.start.line
        let end = selection.end.line

        for lineNumber in start...end {
            let line = buffer.lines[lineNumber] as! String
            let isEmptyLine = line
                .trimmingCharacters(in: .whitespacesAndNewlines)
                .isEmpty

            guard !isEmptyLine else {
                continue
            }

            let length = line.utf16.count
            let range = NSRange(location: 0, length: length)
            let optionalChainingCount = regex
                .matches(in: line, options: [], range: range)
                .count
            let replaced = line.replacingOccurrences(
                of: "\n",
                with: " // \(optionalChainingCount)"
            )
            buffer.lines[lineNumber] = replaced
        }

        completionHandler(nil)
    }
    
}
