//
//  AppDelegate.swift
//  AppSearchDemo
//
//  Created by Syo Ikeda on 10/31/16.
//  Copyright © 2016 Syo Ikeda. All rights reserved.
//

import UIKit
import CoreSpotlight
import MobileCoreServices

@UIApplicationMain
class AppDelegate: UIResponder, UIApplicationDelegate {

    var window: UIWindow?

    func application(_ application: UIApplication, willContinueUserActivityWithType userActivityType: String) -> Bool {
        print(userActivityType == CSQueryContinuationActionType) // true
        return false
    }

    func application(_ application: UIApplication, continue userActivity: NSUserActivity, restorationHandler: @escaping ([Any]?) -> Void) -> Bool {
        guard userActivity.activityType == CSQueryContinuationActionType else {
            return false
        }

        guard
            let userInfo = userActivity.userInfo,
            let keyword = userInfo[CSSearchQueryString] as? String else
        {
            return false
        }

        // 検索キーワードを使用してアプリ内の検索画面を開く。
        // ここではアラートを表示してみる。
        let alert = UIAlertController(title: keyword,
                                      message: "Search Continuation 🎉",
                                      preferredStyle: .alert)
        alert.addAction(UIAlertAction(title: "閉じる", style: .cancel))
        window?.rootViewController?.present(alert, animated: true)

        return true
    }

    func application(_ application: UIApplication, didFinishLaunchingWithOptions launchOptions: [UIApplicationLaunchOptionsKey: Any]?) -> Bool {
        let searchableItems = (1..<6).map { i -> CSSearchableItem in
            let attributeSet = CSSearchableItemAttributeSet(itemContentType: kUTTypeContent as String)
            attributeSet.title = "Title of \(i)"
            attributeSet.contentDescription = "Description of \(i)"

            return CSSearchableItem(
                uniqueIdentifier: "\(i)",
                domainIdentifier: nil,
                attributeSet: attributeSet
            )
        }
        CSSearchableIndex.default().indexSearchableItems(searchableItems, completionHandler: nil)

        return true
    }

    func applicationWillResignActive(_ application: UIApplication) {
        // Sent when the application is about to move from active to inactive state. This can occur for certain types of temporary interruptions (such as an incoming phone call or SMS message) or when the user quits the application and it begins the transition to the background state.
        // Use this method to pause ongoing tasks, disable timers, and invalidate graphics rendering callbacks. Games should use this method to pause the game.
    }

    func applicationDidEnterBackground(_ application: UIApplication) {
        // Use this method to release shared resources, save user data, invalidate timers, and store enough application state information to restore your application to its current state in case it is terminated later.
        // If your application supports background execution, this method is called instead of applicationWillTerminate: when the user quits.
    }

    func applicationWillEnterForeground(_ application: UIApplication) {
        // Called as part of the transition from the background to the active state; here you can undo many of the changes made on entering the background.
    }

    func applicationDidBecomeActive(_ application: UIApplication) {
        // Restart any tasks that were paused (or not yet started) while the application was inactive. If the application was previously in the background, optionally refresh the user interface.
    }

    func applicationWillTerminate(_ application: UIApplication) {
        // Called when the application is about to terminate. Save data if appropriate. See also applicationDidEnterBackground:.
    }


}

