//
//  ViewController.swift
//  AppSearchDemo
//
//  Created by Syo Ikeda on 10/31/16.
//  Copyright © 2016 Syo Ikeda. All rights reserved.
//

import UIKit
import CoreSpotlight

class ViewController: UIViewController {

    override func viewDidLoad() {
        super.viewDidLoad()

        // 比較対象は`title`と`contentDescription`
        let attributes = [ "title", "contentDescription" ]

        // ワイルドカードと、`c`修飾子による大文字・小文字の無視
        let title = "title == 'title OF*'c"
        let description = "contentDescription == '*of*'"

        // `&&`による複数のクエリーの合成
        let queryString = "\(title) && \(description)"

        let searchQuery = CSSearchQuery(queryString: queryString,
                                        attributes: attributes)

        var foundItems: [CSSearchableItem] = []

        // 検索結果は非同期で、バッチに分割されて通知されるので
        // まとめる必要がある
        searchQuery.foundItemsHandler = { items in
            foundItems.append(contentsOf: items)
        }
        // クエリー実行が完了したので見つかった項目を使用する
        searchQuery.completionHandler = { error in
            if let error = error {
                print(error)
                return
            }

            // クエリーではソート順を指定できないので、
            // まとめた結果を自分でソートする必要がある
            let sorted = foundItems.sorted { a, b in
                let idA = a.uniqueIdentifier
                let idB = b.uniqueIdentifier
                return idA.compare(idB) == .orderedAscending
            }
            for item in sorted {
                print(item.uniqueIdentifier,
                      item.attributeSet.title ?? "",
                      item.attributeSet.contentDescription ?? "")
            }
        }
        
        // 非同期で検索クエリーを実行する
        searchQuery.start()
    }

    override func didReceiveMemoryWarning() {
        super.didReceiveMemoryWarning()
        // Dispose of any resources that can be recreated.
    }


}

